package com.zfire.jiasm.syncdata.download.basedata;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.zfire.jiasm.syncdata.constant.DictTypeEnum;
import com.zfire.jiasm.syncdata.constant.InterFaceTypeEnum;
import com.zfire.jiasm.syncdata.data.Token;
import com.zfire.jiasm.syncdata.plus.entity.*;
import com.zfire.jiasm.syncdata.plus.service.*;
import com.zfire.jiasm.syncdata.service.MasterDownloadService;
import com.zfire.jiasm.syncdata.utils.DataUtil;
import com.zfire.jiasm.syncdata.utils.HttpUtil;
import com.zfire.jiasm.syncdata.utils.JSONResult;
import com.zfire.jiasm.syncdata.utils.TokenCenter;
import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.NotNull;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 格力品牌固障代码基础资料下载  同步一次不再同步，PC端使用
 */
@Slf4j
@Component
public class GLPPGuZhandDaiMa {
    @Value("${baseurl}")
    private String baseurl = "";

    @Resource
    TokenCenter tokenCenter;
    @Resource
    BrandService brandService;
    @Resource
    ItfTblAssignGzdmDowloadService itfTblAssignGzdmDowloadService;
    @Resource
    SysDictService sysDictService;
    @Resource
    RepairBugService repairBugService;




    /**
     * 格力品牌固障代码资料信息同步 同步一次不再使用
     * @return
     */
    @Scheduled(fixedDelayString = "${guzdm}")
    @Transactional(rollbackFor = Exception.class)
    public void processGZDMTask() throws Exception {
        if (1==1){
            return;
        }

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Map<String, String> paramMap = new HashMap<String, String>();

        log.info("开始下载格力品牌固障代码信息: \uF0B7{}",sdf.format(new Date()));

        // 提取品牌信息
        Brand brandRec = brandService.lambdaQuery().eq(Brand::getBrand,"格力").one();
        if (brandRec == null){
            log.info("格力品牌信息不存在【brand】");
            return;
        }

        Token token = tokenCenter.getCurrentToken();
        String url = baseurl + InterFaceTypeEnum.GELI_GZDM.getCode() + "/querylist";
        String paramJson= JSON.toJSONString(paramMap);

        JSONResult jsonResult = HttpUtil.httpRequestWithToken(url, "POST", paramJson, token);
        if (jsonResult.getStatus() == null || !jsonResult.getStatus().toString().equals("200")) {
            log.info("下载格力品牌固障代码信息失败！: {}",jsonResult.getMessage());
            return;
        }

        JSONArray jsonArray = (JSONArray) jsonResult.getData();
        if (jsonArray != null) {
            List<ItfTblAssignGzdmDowload> addRec = new ArrayList<>();
            List<ItfTblAssignGzdmDowload> updateRec = new ArrayList<>();

            log.info("下载了{}条数据",jsonArray.size());

            // 数据同步落到同步信息表
            extractedGZDMAddOrUpdate(jsonArray, addRec, updateRec);

            // 数据同步到本地故障现象表
            extractedGZDMLocalAddOrUpdate(brandRec, addRec, updateRec);

            // 新增的插入到表
            if (addRec.size()>0){
                // 先清除再新增
                QueryWrapper del = new QueryWrapper<ItfTblAssignGzdmDowload>()
                        .gt("gzid", 0);
                itfTblAssignGzdmDowloadService.remove(del);

                itfTblAssignGzdmDowloadService.saveBatch(addRec);
                log.info("格力品牌固障代码信息同步新增插入了{}条数据", addRec.size());
                addRec.clear();
            }

            log.info("格力品牌固障代码处理完成: \uF0B7{}",sdf.format(new Date()));
        }else {
            log.info("["+url+"]无数据");
        }
    }


    private void extractedGZDMLocalAddOrUpdate(Brand brandRec, List<ItfTblAssignGzdmDowload> addRec, List<ItfTblAssignGzdmDowload> updateRec) {
        List<RepairBug> addRepairBug = new ArrayList<>();
        // 提取小类字典数据
        List<SysDict> oldSysDictRec =  sysDictService.lambdaQuery()
                .eq(SysDict::getDictType, DictTypeEnum.DICT_TYPE_SMALL_TYPE.getCode())
                .eq(SysDict::getStatus, DictTypeEnum.DICT_TYPE_ON.getCode())
                .list();
        // 小类名称
        List<String> xlname = oldSysDictRec.stream().map(SysDict::getDictValue).collect(Collectors.toList());
        // 小类编号
        Map<String, List<SysDict>> xlMap = oldSysDictRec.stream().collect(Collectors.groupingBy(SysDict::getDictValue));

        // 提取大类字典数据
        List<SysDict> oldDSysDictRec =  sysDictService.lambdaQuery()
                .eq(SysDict::getDictType, DictTypeEnum.DICT_TYPE_MAIN_TYPE.getCode())
                .eq(SysDict::getStatus, DictTypeEnum.DICT_TYPE_ON.getCode()).list();
        // 大类名称
        List<String> dlname = oldDSysDictRec.stream().map(SysDict::getDictValue).collect(Collectors.toList());
        // 大类编号
        Map<String, List<SysDict>> dlMap = oldDSysDictRec.stream().collect(Collectors.groupingBy(SysDict::getDictCode));
        Map<String, List<SysDict>> dlNameMap = oldDSysDictRec.stream().collect(Collectors.groupingBy(SysDict::getDictValue));

        // 获取新增的
        if (addRec.size()>0){
            // 先清除再新增
            QueryWrapper del = new QueryWrapper<RepairBug>()
                    .eq("brand_id", brandRec.getBrandId());
            repairBugService.remove(del);

            for (ItfTblAssignGzdmDowload item : addRec){
                // 类别不存在不新增 这里的类别为类别名称，可能是大类也可能是小类
                // 大类的处理
                // addDL(brandRec, addRepairBug, oldSysDictReclistDL, oldDSysDictRecMapN, oldDSysDictRecMap, item);
                // 小类的处理
                addXL(brandRec, addRepairBug, xlname, xlMap, dlMap, item, dlname, dlNameMap);
            }
        }

        // 新增的插入到表
        if (addRepairBug.size()>0){
            repairBugService.saveBatch(addRepairBug);
            log.info("格力品牌固障代码本地信息表新增插入了{}条数据",addRepairBug.size());
            addRepairBug.clear();
        }
    }

    private void upXL(List<RepairBug> updateRepairBug, List<String> oldSysDictReclist,
                      Map<String, List<SysDict>> oldSysDictRecMap, Map<String, List<SysDict>> oldDSysDictRecMap,
                      Map<String, List<RepairBug>> oldRepairBugRecMap, ItfTblAssignGzdmDowload item) {
        Boolean flag;
        flag = Boolean.FALSE;
        // 类别存在的修改
        if (oldSysDictReclist.contains(item.getLeib())){
            upRepairBug(updateRepairBug, oldSysDictRecMap, oldDSysDictRecMap, oldRepairBugRecMap, item, flag);
        } else {
            // 类别不存在的修改
            upRepairBugT(updateRepairBug, oldRepairBugRecMap, item, flag);
        }
    }

    private void upRepairBugT(List<RepairBug> updateRepairBug, Map<String, List<RepairBug>> oldRepairBugRecMap, ItfTblAssignGzdmDowload item, Boolean flag) {
        RepairBug old = oldRepairBugRecMap.get(String.valueOf(item.getGzid())).get(0);
        if (!old.getBugObj().equals(item.getGzmc())){
            old.setBugObj(item.getGzmc());
            flag = Boolean.TRUE;
        }
        if (!old.getBugObjCode().equals(item.getGzno())){
            old.setBugObjCode(item.getGzmc());
            flag = Boolean.TRUE;
        }

        // 修改的为有效
        if (item.getFlag().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
            if (old.getStatus().equals(DictTypeEnum.DICT_TYPE_OFF.getCode())){
                old.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
                flag = Boolean.TRUE;
            }
        } else {
            if (old.getStatus().equals(DictTypeEnum.DICT_TYPE_ON.getCode())){
                old.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
                flag = Boolean.TRUE;
            }
        }
        if (flag){
            old.setUpdateBy("system");
            old.setUpdateTime(new Date());
            if (item.getLastModifiedBy() !=null ){
                old.setUpdateBy(item.getLastModifiedBy());
            }
            if (item.getLastModifiedDate() !=null ){
                old.setUpdateTime(item.getLastModifiedDate());
            }
            updateRepairBug.add(old);
        }
    }

    private void upRepairBug(List<RepairBug> updateRepairBug, Map<String, List<SysDict>> oldSysDictRecMap, Map<String, List<SysDict>> oldDSysDictRecMap, Map<String, List<RepairBug>> oldRepairBugRecMap, ItfTblAssignGzdmDowload item, Boolean flag) {
        RepairBug old = oldRepairBugRecMap.get(String.valueOf(item.getGzid())).get(0);

        if (oldSysDictRecMap.get(item.getLeib()).get(0)!=null){
            if (!old.getSmallId().equals(oldSysDictRecMap.get(item.getLeib()).get(0).getDictCode())){
                flag = Boolean.TRUE;
                old.setSmallId(oldSysDictRecMap.get(item.getLeib()).get(0).getDictCode());
                old.setSmallName(oldSysDictRecMap.get(item.getLeib()).get(0).getDictValue());
                old.setMainId(oldSysDictRecMap.get(item.getLeib()).get(0).getParentDictCode());
                old.setMainName(oldDSysDictRecMap.get(old.getMainId()).get(0).getDictValue());
                old.setMainFlag(oldDSysDictRecMap.get(old.getMainId()).get(0).getFlag());
            }
        }
        if (!old.getBugObjCode().equals(item.getGzno())){
            old.setBugObjCode(item.getGzno());
            flag = Boolean.TRUE;
        }
        if (!old.getBugObj().equals(item.getGzmc())){
            old.setBugObj(item.getGzmc());
            flag = Boolean.TRUE;
        }
        // 修改的为有效
        if (item.getFlag().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
            if (old.getStatus().equals(DictTypeEnum.DICT_TYPE_OFF.getCode())){
                old.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
                flag = Boolean.TRUE;
            }
        } else {
            if (old.getStatus().equals(DictTypeEnum.DICT_TYPE_ON.getCode())){
                old.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
                flag = Boolean.TRUE;
            }
        }
        if (flag){
            old.setUpdateBy("system");
            old.setUpdateTime(new Date());
            if (item.getLastModifiedBy() !=null ){
                old.setUpdateBy(item.getLastModifiedBy());
            }
            if (item.getLastModifiedDate() !=null ){
                old.setUpdateTime(item.getLastModifiedDate());
            }
            updateRepairBug.add(old);
        }
    }

    @NotNull
    private void upDL(List<RepairBug> updateRepairBug, Map<String, List<SysDict>> oldSysDictRecMap, List<String> oldSysDictReclistDL, Map<String, List<SysDict>> oldDSysDictRecMapN, Map<String, List<SysDict>> oldDSysDictRecMap, Map<String, List<RepairBug>> oldRepairBugRecMap, ItfTblAssignGzdmDowload item) {
        Boolean flag;
        flag = Boolean.FALSE;
        if (oldSysDictReclistDL.contains(item.getLeib())){
            SysDict v = oldSysDictRecMap.get(item.getLeib()).get(0);
            RepairBug old = oldRepairBugRecMap.get(item.getGzid()).get(0);

            if (!old.getMainId().equals(oldDSysDictRecMapN.get(item.getLeib()).get(0).getDictCode())){
                flag = Boolean.TRUE;
                // 大类处理
                old.setMainId(oldDSysDictRecMapN.get(item.getLeib()).get(0).getDictCode());
                old.setMainName(item.getLeib());
                old.setMainFlag(oldDSysDictRecMap.get(old.getMainId()).get(0).getFlag());
            }

            if (!old.getBugObj().equals(item.getGzmc())){
                old.setBugObj(item.getGzmc());
                flag = Boolean.TRUE;
            }
            if (item.getGzno() !=null || old.getBugObjCode() !=null ){
                if (item.getGzno() !=null && old.getBugObjCode() !=null){
                    if (!item.getGzno().equals(old.getBugObjCode())){
                        old.setBugObjCode(item.getGzno());
                        flag = Boolean.TRUE;
                    }
                } else {
                    flag = Boolean.TRUE;
                    if (item.getGzno() !=null){
                        old.setBugObjCode(item.getGzno());
                    } else {
                        old.setBugObjCode(null);
                    }
                }
            }

            // 修改的为有效
            if (item.getFlag().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
                if (old.getStatus().equals(DictTypeEnum.DICT_TYPE_OFF.getCode())){
                    old.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
                    flag = Boolean.TRUE;
                }
            } else {
                if (old.getStatus().equals(DictTypeEnum.DICT_TYPE_ON.getCode())){
                    old.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
                    flag = Boolean.TRUE;
                }
            }
            if (flag){
                old.setUpdateBy("system");
                old.setUpdateTime(new Date());
                if (item.getLastModifiedBy() !=null ){
                    old.setUpdateBy(item.getLastModifiedBy());
                }
                if (item.getLastModifiedDate() !=null ){
                    old.setUpdateTime(item.getLastModifiedDate());
                }
                updateRepairBug.add(old);
            }
        }
    }

    private void addDL(Brand brandRec, List<RepairBug> addRepairBug, List<String> oldSysDictReclistDL, Map<String, List<SysDict>> oldDSysDictRecMapN, Map<String, List<SysDict>> oldDSysDictRecMap, ItfTblAssignGzdmDowload item) {
        if (oldSysDictReclistDL.contains(item.getLeib())){
            RepairBug v = new RepairBug();
            v.setBugId(UUID.randomUUID().toString());
            v.setGzid(String.valueOf(item.getGzid()));
            v.setBrandId(brandRec.getBrandId());
            v.setBrandName(brandRec.getBrand());
            // 大类处理
            v.setMainId(oldDSysDictRecMapN.get(item.getLeib()).get(0).getDictCode());
            v.setMainName(item.getLeib());
            v.setMainFlag(oldDSysDictRecMap.get(v.getMainId()).get(0).getFlag());
            v.setBugObj(item.getGzmc());
            if (item.getGzno() !=null ){
                v.setBugObjCode(item.getGzno());
            }
            v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
            if (item.getFlag().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
                v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
            }
            v.setCreateBy("system");
            v.setCreateTime(new Date());
            if (item.getCjren() !=null){
                v.setCreateBy(item.getCjren());
            }
            if (item.getCjdt() != null){
                v.setCreateTime(item.getCjdt());
            }
            addRepairBug.add(v);
        }
    }

    private void addXL(Brand brandRec, List<RepairBug> addRepairBug, List<String> xlname, Map<String, List<SysDict>> xlMap,
                       Map<String, List<SysDict>> dlMap, ItfTblAssignGzdmDowload item, List<String> dlname,Map<String, List<SysDict>> dlNameMap) {
        Boolean flag = Boolean.FALSE;
        // leib为小类的名称
        if (xlname.contains(item.getLeib())){
            addRepairBugCheck(brandRec, addRepairBug, xlMap, dlMap, item);
        } else {
            // 部分小类特殊处理
            if (!StringUtils.isEmpty(item.getLeib())){
                // 小类的处理
                flag = addRepairBugCheckt(brandRec, addRepairBug, xlMap, dlMap, item);
                if (flag){
                    // 小类做为大类处理
                    flag = addRepairBugCheckd(brandRec, addRepairBug, item,dlNameMap);
                    if (flag){
                        // 无法对应到类别信息直接添加
                        addRepairBug(brandRec, addRepairBug, item);
                    }
                }
            } else {
                // 无小类信息直接添加
                addRepairBug(brandRec, addRepairBug, item);
            }
        }
    }

    private void addXLbak(Brand brandRec, List<RepairBug> addRepairBug, List<String> xlname, Map<String, List<SysDict>> xlMap,
                       Map<String, List<SysDict>> dlMap, ItfTblAssignGzdmDowload item) {
        // leib为小类的名称
        if (xlname.contains(item.getLeib())){
            addRepairBugCheck(brandRec, addRepairBug, xlMap, dlMap, item);
        } else {
            // 无小类信息直接添加
            addRepairBug(brandRec, addRepairBug, item);
        }
    }

    private void addRepairBugCheck(Brand brandRec, List<RepairBug> addRepairBug, Map<String, List<SysDict>> xlMap,
                                   Map<String, List<SysDict>> dlMap, ItfTblAssignGzdmDowload item) {
        RepairBug v = new RepairBug();
        v.setBugId(UUID.randomUUID().toString());
        v.setGzid(String.valueOf(item.getGzid()));
        v.setBrandId(brandRec.getBrandId());
        v.setBrandName(brandRec.getBrand());
        // 类别不为空时 key名称
        if (xlMap.get(item.getLeib()).get(0)!=null){
            // 小类编号
            v.setSmallId(xlMap.get(item.getLeib()).get(0).getDictCode());
            // 小类名称
            v.setSmallName(xlMap.get(item.getLeib()).get(0).getDictValue());
            // 小类有对应的父类时 提取父类信息
            if (!StringUtils.isEmpty(xlMap.get(item.getLeib()).get(0).getParentDictCode())){
                v.setMainId(xlMap.get(item.getLeib()).get(0).getParentDictCode());
                v.setMainName(dlMap.get(v.getMainId()).get(0).getDictValue());
                v.setMainFlag(dlMap.get(v.getMainId()).get(0).getFlag());
            }
        }
        v.setBugObj(item.getGzmc());
        v.setBugObjCode(item.getGzno());
        v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
        if (item.getFlag().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
            v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
        }
        v.setCreateBy("system");
        v.setCreateTime(new Date());
        if (item.getCjren() !=null){
            v.setCreateBy(item.getCjren());
        }
        if (item.getCjdt() != null){
            v.setCreateTime(item.getCjdt());
        }
        addRepairBug.add(v);
    }

    private Boolean addRepairBugCheckt(@NotNull Brand brandRec, List<RepairBug> addRepairBug, Map<String, List<SysDict>> xlMap,
                                       Map<String, List<SysDict>> dlMap, ItfTblAssignGzdmDowload item) {
        RepairBug v = new RepairBug();
        v.setBugId(UUID.randomUUID().toString());
        v.setGzid(String.valueOf(item.getGzid()));
        v.setBrandId(brandRec.getBrandId());
        v.setBrandName(brandRec.getBrand());
        // 类别不为空时 key名称
        String leibname = "";
        if (item.getLeib().equals("煤气灶")){
            leibname="燃气灶";
        } else if (item.getLeib().equals("家用热水器") || item.getLeib().equals("商用热水器")){
            leibname="家用空气能热水器";
        } else if (item.getLeib().equals("电风扇/冷风扇/塔扇")){
            leibname="电风扇/冷风扇/大厦扇";
        } else if (item.getLeib().equals("电风扇/冷风扇/塔扇")){
            leibname="电风扇/冷风扇/大厦扇";
        } else if (item.getLeib().equals("抽油烟机")){
            leibname="吸油烟机";
        }
        if (StringUtils.isEmpty(leibname)) {
            return Boolean.TRUE;
        }
        if (!xlMap.containsKey(leibname)){
            return Boolean.TRUE;
        }

        // 小类编号
        v.setSmallId(xlMap.get(leibname).get(0).getDictCode());
        // 小类名称
        v.setSmallName(xlMap.get(leibname).get(0).getDictValue());
        // 小类有对应的父类时 提取父类信息
        if (!StringUtils.isEmpty(xlMap.get(leibname).get(0).getParentDictCode())){
            v.setMainId(xlMap.get(leibname).get(0).getParentDictCode());
            v.setMainName(dlMap.get(v.getMainId()).get(0).getDictValue());
            v.setMainFlag(dlMap.get(v.getMainId()).get(0).getFlag());
        }

        v.setBugObj(item.getGzmc());
        v.setBugObjCode(item.getGzno());
        v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
        if (item.getFlag().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
            v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
        }
        v.setCreateBy("system");
        v.setCreateTime(new Date());
        if (item.getCjren() !=null){
            v.setCreateBy(item.getCjren());
        }
        if (item.getCjdt() != null){
            v.setCreateTime(item.getCjdt());
        }
        addRepairBug.add(v);
        return Boolean.FALSE;
    }

    private Boolean addRepairBugCheckd(Brand brandRec, List<RepairBug> addRepairBug, ItfTblAssignGzdmDowload item,
                                       Map<String, List<SysDict>> dlNameMap) {
        RepairBug v = new RepairBug();
        v.setBugId(UUID.randomUUID().toString());
        v.setGzid(String.valueOf(item.getGzid()));
        v.setBrandId(brandRec.getBrandId());
        v.setBrandName(brandRec.getBrand());
        // 类别不为空时 key名称
        String leibname = "";
        if (item.getLeib().equals("空调")){
            leibname="家用空调";
        } else if (item.getLeib().equals("家用热水器") || item.getLeib().equals("商用热水器")){
            leibname="家用空气能热水器";
        } else if (item.getLeib().equals("晶弘冰箱")){
            leibname="晶弘冰箱";
        } else if (item.getLeib().equals("洗衣机")){
            leibname="洗衣机";
        } else if (item.getLeib().equals("商用空调")){
            leibname="商用空调";
        } else if (item.getLeib().equals("手机")){
            leibname="手机";
        } else if (item.getLeib().equals("移动电源")){
            leibname="移动电源";
        } else if (item.getLeib().equals("智能门锁")){
            leibname="智能门锁";
        }
        if (StringUtils.isEmpty(leibname)) {
            return Boolean.TRUE;
        }
        if (!dlNameMap.containsKey(leibname)){
            return Boolean.TRUE;
        }
        v.setMainId(dlNameMap.get(leibname).get(0).getDictCode());
        v.setMainName(dlNameMap.get(leibname).get(0).getDictValue());
        v.setMainFlag(dlNameMap.get(leibname).get(0).getFlag());
        v.setBugObj(item.getGzmc());
        v.setBugObjCode(item.getGzno());
        v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
        if (item.getFlag().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
            v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
        }
        v.setCreateBy("system");
        v.setCreateTime(new Date());
        if (item.getCjren() !=null){
            v.setCreateBy(item.getCjren());
        }
        if (item.getCjdt() != null){
            v.setCreateTime(item.getCjdt());
        }
        addRepairBug.add(v);
        return Boolean.FALSE;
    }

    private void addRepairBugCheckBak(Brand brandRec, List<RepairBug> addRepairBug, Map<String, List<SysDict>> oldSysDictRecMap, Map<String, List<SysDict>> oldDSysDictRecMap, ItfTblAssignGzdmDowload item) {
        RepairBug v = new RepairBug();
        v.setBugId(UUID.randomUUID().toString());
        v.setGzid(String.valueOf(item.getGzid()));
        v.setBrandId(brandRec.getBrandId());
        v.setBrandName(brandRec.getBrand());
        // 类别不为空时
        if (oldSysDictRecMap.get(item.getLeib()).get(0)!=null){
            // 小类编号
            v.setSmallId(oldSysDictRecMap.get(item.getLeib()).get(0).getDictCode());
            // 小类名称
            v.setSmallName(oldSysDictRecMap.get(item.getLeib()).get(0).getDictValue());
            // 小类有对应的父类时 提取父类信息
            if (!StringUtils.isEmpty(oldSysDictRecMap.get(item.getLeib()).get(0).getParentDictCode())){
                v.setMainId(oldSysDictRecMap.get(item.getLeib()).get(0).getParentDictCode());
                v.setMainName(oldDSysDictRecMap.get(v.getMainId()).get(0).getDictValue());
                v.setMainFlag(oldDSysDictRecMap.get(v.getMainId()).get(0).getFlag());
            }
        }
        v.setBugObj(item.getGzmc());
        v.setBugObjCode(item.getGzno());
        v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
        if (item.getFlag().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
            v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
        }
        v.setCreateBy("system");
        v.setCreateTime(new Date());
        if (item.getCjren() !=null){
            v.setCreateBy(item.getCjren());
        }
        if (item.getCjdt() != null){
            v.setCreateTime(item.getCjdt());
        }
        addRepairBug.add(v);
    }

    private void addRepairBug(Brand brandRec, List<RepairBug> addRepairBug, ItfTblAssignGzdmDowload item) {
        RepairBug v = new RepairBug();
        v.setBugId(UUID.randomUUID().toString());
        v.setGzid(String.valueOf(item.getGzid()));
        v.setBrandId(brandRec.getBrandId());
        v.setBrandName(brandRec.getBrand());
        v.setMainId("");
        v.setBugObj(item.getGzmc());
        v.setBugObjCode(item.getGzno());
        v.setStatus(DictTypeEnum.DICT_TYPE_OFF.getCode());
        if (item.getFlag().equals(DictTypeEnum.DICT_TYPE_FLAG_ON.getCode())){
            v.setStatus(DictTypeEnum.DICT_TYPE_ON.getCode());
        }
        v.setCreateBy("system");
        v.setCreateTime(new Date());
        if (item.getCjren() !=null){
            v.setCreateBy(item.getCjren());
        }
        if (item.getCjdt() != null){
            v.setCreateTime(item.getCjdt());
        }
        addRepairBug.add(v);
    }


    private void extractedGZDMAddOrUpdate(JSONArray jsonArray, List<ItfTblAssignGzdmDowload> addRec, List<ItfTblAssignGzdmDowload> updateRec) {
        String synTaskNo = UUID.randomUUID().toString();

        for (int i = 0; i < jsonArray.size(); i++) {
            JSONObject aData = jsonArray.getJSONObject(i);
            ItfTblAssignGzdmDowload item = JSON.toJavaObject(aData,ItfTblAssignGzdmDowload.class);
            if (StringUtils.isEmpty(item.getGzno())){
                item.setGzno("");
            }
            // 新增或修改数据
            if (StringUtils.isEmpty(item.getLeib())){
                item.setLeib("");
            }
            if (StringUtils.isEmpty(item.getGzmc())){
                item.setGzmc("");
            }
            if (StringUtils.isEmpty(item.getFlag())){
                item.setFlag("有效");
            }
            if (StringUtils.isEmpty(item.getCjwdno())){
                item.setCjwdno("");
            }
            if (item.getPxdj()==null){
                item.setPxdj(0);
            }

            // 新增
            item.setSynTaskNo(synTaskNo);
            if (item.getCreatedBy() ==null){
                item.setCreatedBy("system");
            }
            if (item.getCreatedDate() == null){
                item.setCreatedDate(new Date());
            }
            addRec.add(item);
        }
    }
}
